@@ -3,8 +3,7 @@ use MooseX::Declare;
 use 5.010;
 
 ## no critic (RequireUseStrict)
-class Tapper::MCP::Scheduler::Controller
-{
+class Tapper::MCP::Scheduler::Controller extends Tapper::Base with Tapper::MCP::Net::TAP {
         use Tapper::Model 'model';
         use aliased 'Tapper::MCP::Scheduler::Algorithm';
         use aliased 'Tapper::MCP::Scheduler::PrioQueue';
@@ -22,6 +21,9 @@ class Tapper::MCP::Scheduler::Controller
                                          }
                          );
 
+        has testrun   => (is => 'rw');
+        has cfg       => (is => 'ro', default => sub {{}});
+
 
 =head2
 
@@ -113,8 +115,8 @@ fits any of the free hosts.
                          };
                         if ($error or $@) {
                                 $error //=$@;
-                                my $net    = Tapper::MCP::Net->new();
-                                $net->tap_report_send($job->testrun_id, [{error => 1, msg => $error}]);
+                                $self->testrun($job);
+                                $self->tap_report_send([{error => 1, msg => $error}], $self->mcp_headerlines());
                                 $self->mark_job_as_finished($job);
                                 return;
                         }
